@@ -89,16 +89,16 @@ class KafkaClient:
 
     def create_cluster(
         self,
-        BrokerNodeGroupInfo: BrokerNodeGroupInfoTypeDef,
+        BrokerNodeGroupInfo: "BrokerNodeGroupInfoTypeDef",
         ClusterName: str,
         KafkaVersion: str,
         NumberOfBrokerNodes: int,
-        ClientAuthentication: ClientAuthenticationTypeDef = None,
-        ConfigurationInfo: ConfigurationInfoTypeDef = None,
-        EncryptionInfo: EncryptionInfoTypeDef = None,
+        ClientAuthentication: "ClientAuthenticationTypeDef" = None,
+        ConfigurationInfo: "ConfigurationInfoTypeDef" = None,
+        EncryptionInfo: "EncryptionInfoTypeDef" = None,
         EnhancedMonitoring: Literal["DEFAULT", "PER_BROKER", "PER_TOPIC_PER_BROKER"] = None,
         OpenMonitoring: OpenMonitoringInfoTypeDef = None,
-        LoggingInfo: LoggingInfoTypeDef = None,
+        LoggingInfo: "LoggingInfoTypeDef" = None,
         Tags: Dict[str, str] = None,
     ) -> CreateClusterResponseTypeDef:
         """
@@ -238,14 +238,14 @@ class KafkaClient:
         self,
         ClusterArn: str,
         CurrentVersion: str,
-        TargetBrokerEBSVolumeInfo: List[BrokerEBSVolumeInfoTypeDef],
+        TargetBrokerEBSVolumeInfo: List["BrokerEBSVolumeInfoTypeDef"],
     ) -> UpdateBrokerStorageResponseTypeDef:
         """
         [Client.update_broker_storage documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/kafka.html#Kafka.Client.update_broker_storage)
         """
 
     def update_cluster_configuration(
-        self, ClusterArn: str, ConfigurationInfo: ConfigurationInfoTypeDef, CurrentVersion: str
+        self, ClusterArn: str, ConfigurationInfo: "ConfigurationInfoTypeDef", CurrentVersion: str
     ) -> UpdateClusterConfigurationResponseTypeDef:
         """
         [Client.update_cluster_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/kafka.html#Kafka.Client.update_cluster_configuration)
@@ -256,7 +256,7 @@ class KafkaClient:
         ClusterArn: str,
         CurrentVersion: str,
         TargetKafkaVersion: str,
-        ConfigurationInfo: ConfigurationInfoTypeDef = None,
+        ConfigurationInfo: "ConfigurationInfoTypeDef" = None,
     ) -> UpdateClusterKafkaVersionResponseTypeDef:
         """
         [Client.update_cluster_kafka_version documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/kafka.html#Kafka.Client.update_cluster_kafka_version)
@@ -268,7 +268,7 @@ class KafkaClient:
         CurrentVersion: str,
         EnhancedMonitoring: Literal["DEFAULT", "PER_BROKER", "PER_TOPIC_PER_BROKER"] = None,
         OpenMonitoring: OpenMonitoringInfoTypeDef = None,
-        LoggingInfo: LoggingInfoTypeDef = None,
+        LoggingInfo: "LoggingInfoTypeDef" = None,
     ) -> UpdateMonitoringResponseTypeDef:
         """
         [Client.update_monitoring documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/kafka.html#Kafka.Client.update_monitoring)
