@@ -23,58 +23,58 @@ else:
 
 __all__ = (
     "BrokerEBSVolumeInfoTypeDef",
-    "EBSStorageInfoTypeDef",
-    "StorageInfoTypeDef",
+    "BrokerLogsTypeDef",
     "BrokerNodeGroupInfoTypeDef",
-    "TlsTypeDef",
+    "BrokerNodeInfoTypeDef",
+    "BrokerSoftwareInfoTypeDef",
     "ClientAuthenticationTypeDef",
-    "ConfigurationInfoTypeDef",
-    "CreateClusterResponseTypeDef",
-    "ConfigurationRevisionTypeDef",
-    "CreateConfigurationResponseTypeDef",
-    "DeleteClusterResponseTypeDef",
+    "CloudWatchLogsTypeDef",
+    "ClusterInfoTypeDef",
+    "ClusterOperationInfoTypeDef",
     "ClusterOperationStepInfoTypeDef",
     "ClusterOperationStepTypeDef",
-    "ErrorInfoTypeDef",
-    "CloudWatchLogsTypeDef",
-    "FirehoseTypeDef",
-    "S3TypeDef",
-    "BrokerLogsTypeDef",
-    "LoggingInfoTypeDef",
-    "JmxExporterTypeDef",
-    "NodeExporterTypeDef",
-    "PrometheusTypeDef",
-    "OpenMonitoringTypeDef",
-    "MutableClusterInfoTypeDef",
-    "ClusterOperationInfoTypeDef",
-    "DescribeClusterOperationResponseTypeDef",
-    "BrokerSoftwareInfoTypeDef",
+    "CompatibleKafkaVersionTypeDef",
+    "ConfigurationInfoTypeDef",
+    "ConfigurationRevisionTypeDef",
+    "ConfigurationTypeDef",
+    "EBSStorageInfoTypeDef",
     "EncryptionAtRestTypeDef",
     "EncryptionInTransitTypeDef",
     "EncryptionInfoTypeDef",
+    "ErrorInfoTypeDef",
+    "FirehoseTypeDef",
+    "JmxExporterInfoTypeDef",
+    "JmxExporterTypeDef",
+    "KafkaVersionTypeDef",
+    "LoggingInfoTypeDef",
+    "MutableClusterInfoTypeDef",
+    "NodeExporterInfoTypeDef",
+    "NodeExporterTypeDef",
+    "NodeInfoTypeDef",
+    "OpenMonitoringTypeDef",
+    "PrometheusInfoTypeDef",
+    "PrometheusTypeDef",
+    "S3TypeDef",
     "StateInfoTypeDef",
-    "ClusterInfoTypeDef",
+    "StorageInfoTypeDef",
+    "TlsTypeDef",
+    "ZookeeperNodeInfoTypeDef",
+    "CreateClusterResponseTypeDef",
+    "CreateConfigurationResponseTypeDef",
+    "DeleteClusterResponseTypeDef",
+    "DescribeClusterOperationResponseTypeDef",
     "DescribeClusterResponseTypeDef",
     "DescribeConfigurationResponseTypeDef",
     "DescribeConfigurationRevisionResponseTypeDef",
     "GetBootstrapBrokersResponseTypeDef",
-    "CompatibleKafkaVersionTypeDef",
     "GetCompatibleKafkaVersionsResponseTypeDef",
     "ListClusterOperationsResponseTypeDef",
     "ListClustersResponseTypeDef",
     "ListConfigurationRevisionsResponseTypeDef",
-    "ConfigurationTypeDef",
     "ListConfigurationsResponseTypeDef",
-    "KafkaVersionTypeDef",
     "ListKafkaVersionsResponseTypeDef",
-    "BrokerNodeInfoTypeDef",
-    "ZookeeperNodeInfoTypeDef",
-    "NodeInfoTypeDef",
     "ListNodesResponseTypeDef",
     "ListTagsForResourceResponseTypeDef",
-    "JmxExporterInfoTypeDef",
-    "NodeExporterInfoTypeDef",
-    "PrometheusInfoTypeDef",
     "OpenMonitoringInfoTypeDef",
     "PaginatorConfigTypeDef",
     "UpdateBrokerCountResponseTypeDef",
@@ -88,10 +88,10 @@ BrokerEBSVolumeInfoTypeDef = TypedDict(
     "BrokerEBSVolumeInfoTypeDef", {"KafkaBrokerNodeId": str, "VolumeSizeGB": int}
 )
 
-EBSStorageInfoTypeDef = TypedDict("EBSStorageInfoTypeDef", {"VolumeSize": int}, total=False)
-
-StorageInfoTypeDef = TypedDict(
-    "StorageInfoTypeDef", {"EbsStorageInfo": EBSStorageInfoTypeDef}, total=False
+BrokerLogsTypeDef = TypedDict(
+    "BrokerLogsTypeDef",
+    {"CloudWatchLogs": "CloudWatchLogsTypeDef", "Firehose": "FirehoseTypeDef", "S3": "S3TypeDef"},
+    total=False,
 )
 
 _RequiredBrokerNodeGroupInfoTypeDef = TypedDict(
@@ -102,7 +102,7 @@ _OptionalBrokerNodeGroupInfoTypeDef = TypedDict(
     {
         "BrokerAZDistribution": Literal["DEFAULT"],
         "SecurityGroups": List[str],
-        "StorageInfo": StorageInfoTypeDef,
+        "StorageInfo": "StorageInfoTypeDef",
     },
     total=False,
 )
@@ -114,24 +114,99 @@ class BrokerNodeGroupInfoTypeDef(
     pass
 
 
-TlsTypeDef = TypedDict("TlsTypeDef", {"CertificateAuthorityArnList": List[str]}, total=False)
-
-ClientAuthenticationTypeDef = TypedDict(
-    "ClientAuthenticationTypeDef", {"Tls": TlsTypeDef}, total=False
-)
-
-ConfigurationInfoTypeDef = TypedDict("ConfigurationInfoTypeDef", {"Arn": str, "Revision": int})
-
-CreateClusterResponseTypeDef = TypedDict(
-    "CreateClusterResponseTypeDef",
+BrokerNodeInfoTypeDef = TypedDict(
+    "BrokerNodeInfoTypeDef",
     {
-        "ClusterArn": str,
-        "ClusterName": str,
-        "State": Literal["ACTIVE", "CREATING", "UPDATING", "DELETING", "FAILED"],
+        "AttachedENIId": str,
+        "BrokerId": float,
+        "ClientSubnet": str,
+        "ClientVpcIpAddress": str,
+        "CurrentBrokerSoftwareInfo": "BrokerSoftwareInfoTypeDef",
+        "Endpoints": List[str],
     },
     total=False,
 )
 
+BrokerSoftwareInfoTypeDef = TypedDict(
+    "BrokerSoftwareInfoTypeDef",
+    {"ConfigurationArn": str, "ConfigurationRevision": int, "KafkaVersion": str},
+    total=False,
+)
+
+ClientAuthenticationTypeDef = TypedDict(
+    "ClientAuthenticationTypeDef", {"Tls": "TlsTypeDef"}, total=False
+)
+
+_RequiredCloudWatchLogsTypeDef = TypedDict("_RequiredCloudWatchLogsTypeDef", {"Enabled": bool})
+_OptionalCloudWatchLogsTypeDef = TypedDict(
+    "_OptionalCloudWatchLogsTypeDef", {"LogGroup": str}, total=False
+)
+
+
+class CloudWatchLogsTypeDef(_RequiredCloudWatchLogsTypeDef, _OptionalCloudWatchLogsTypeDef):
+    pass
+
+
+ClusterInfoTypeDef = TypedDict(
+    "ClusterInfoTypeDef",
+    {
+        "ActiveOperationArn": str,
+        "BrokerNodeGroupInfo": "BrokerNodeGroupInfoTypeDef",
+        "ClientAuthentication": "ClientAuthenticationTypeDef",
+        "ClusterArn": str,
+        "ClusterName": str,
+        "CreationTime": datetime,
+        "CurrentBrokerSoftwareInfo": "BrokerSoftwareInfoTypeDef",
+        "CurrentVersion": str,
+        "EncryptionInfo": "EncryptionInfoTypeDef",
+        "EnhancedMonitoring": Literal["DEFAULT", "PER_BROKER", "PER_TOPIC_PER_BROKER"],
+        "OpenMonitoring": "OpenMonitoringTypeDef",
+        "LoggingInfo": "LoggingInfoTypeDef",
+        "NumberOfBrokerNodes": int,
+        "State": Literal["ACTIVE", "CREATING", "UPDATING", "DELETING", "FAILED"],
+        "StateInfo": "StateInfoTypeDef",
+        "Tags": Dict[str, str],
+        "ZookeeperConnectString": str,
+    },
+    total=False,
+)
+
+ClusterOperationInfoTypeDef = TypedDict(
+    "ClusterOperationInfoTypeDef",
+    {
+        "ClientRequestId": str,
+        "ClusterArn": str,
+        "CreationTime": datetime,
+        "EndTime": datetime,
+        "ErrorInfo": "ErrorInfoTypeDef",
+        "OperationArn": str,
+        "OperationState": str,
+        "OperationSteps": List["ClusterOperationStepTypeDef"],
+        "OperationType": str,
+        "SourceClusterInfo": "MutableClusterInfoTypeDef",
+        "TargetClusterInfo": "MutableClusterInfoTypeDef",
+    },
+    total=False,
+)
+
+ClusterOperationStepInfoTypeDef = TypedDict(
+    "ClusterOperationStepInfoTypeDef", {"StepStatus": str}, total=False
+)
+
+ClusterOperationStepTypeDef = TypedDict(
+    "ClusterOperationStepTypeDef",
+    {"StepInfo": "ClusterOperationStepInfoTypeDef", "StepName": str},
+    total=False,
+)
+
+CompatibleKafkaVersionTypeDef = TypedDict(
+    "CompatibleKafkaVersionTypeDef",
+    {"SourceVersion": str, "TargetVersions": List[str]},
+    total=False,
+)
+
+ConfigurationInfoTypeDef = TypedDict("ConfigurationInfoTypeDef", {"Arn": str, "Revision": int})
+
 _RequiredConfigurationRevisionTypeDef = TypedDict(
     "_RequiredConfigurationRevisionTypeDef", {"CreationTime": datetime, "Revision": int}
 )
@@ -146,128 +221,19 @@ class ConfigurationRevisionTypeDef(
     pass
 
 
-CreateConfigurationResponseTypeDef = TypedDict(
-    "CreateConfigurationResponseTypeDef",
+ConfigurationTypeDef = TypedDict(
+    "ConfigurationTypeDef",
     {
         "Arn": str,
         "CreationTime": datetime,
-        "LatestRevision": ConfigurationRevisionTypeDef,
+        "Description": str,
+        "KafkaVersions": List[str],
+        "LatestRevision": "ConfigurationRevisionTypeDef",
         "Name": str,
     },
-    total=False,
 )
 
-DeleteClusterResponseTypeDef = TypedDict(
-    "DeleteClusterResponseTypeDef",
-    {"ClusterArn": str, "State": Literal["ACTIVE", "CREATING", "UPDATING", "DELETING", "FAILED"]},
-    total=False,
-)
-
-ClusterOperationStepInfoTypeDef = TypedDict(
-    "ClusterOperationStepInfoTypeDef", {"StepStatus": str}, total=False
-)
-
-ClusterOperationStepTypeDef = TypedDict(
-    "ClusterOperationStepTypeDef",
-    {"StepInfo": ClusterOperationStepInfoTypeDef, "StepName": str},
-    total=False,
-)
-
-ErrorInfoTypeDef = TypedDict(
-    "ErrorInfoTypeDef", {"ErrorCode": str, "ErrorString": str}, total=False
-)
-
-_RequiredCloudWatchLogsTypeDef = TypedDict("_RequiredCloudWatchLogsTypeDef", {"Enabled": bool})
-_OptionalCloudWatchLogsTypeDef = TypedDict(
-    "_OptionalCloudWatchLogsTypeDef", {"LogGroup": str}, total=False
-)
-
-
-class CloudWatchLogsTypeDef(_RequiredCloudWatchLogsTypeDef, _OptionalCloudWatchLogsTypeDef):
-    pass
-
-
-_RequiredFirehoseTypeDef = TypedDict("_RequiredFirehoseTypeDef", {"Enabled": bool})
-_OptionalFirehoseTypeDef = TypedDict(
-    "_OptionalFirehoseTypeDef", {"DeliveryStream": str}, total=False
-)
-
-
-class FirehoseTypeDef(_RequiredFirehoseTypeDef, _OptionalFirehoseTypeDef):
-    pass
-
-
-_RequiredS3TypeDef = TypedDict("_RequiredS3TypeDef", {"Enabled": bool})
-_OptionalS3TypeDef = TypedDict("_OptionalS3TypeDef", {"Bucket": str, "Prefix": str}, total=False)
-
-
-class S3TypeDef(_RequiredS3TypeDef, _OptionalS3TypeDef):
-    pass
-
-
-BrokerLogsTypeDef = TypedDict(
-    "BrokerLogsTypeDef",
-    {"CloudWatchLogs": CloudWatchLogsTypeDef, "Firehose": FirehoseTypeDef, "S3": S3TypeDef},
-    total=False,
-)
-
-LoggingInfoTypeDef = TypedDict("LoggingInfoTypeDef", {"BrokerLogs": BrokerLogsTypeDef})
-
-JmxExporterTypeDef = TypedDict("JmxExporterTypeDef", {"EnabledInBroker": bool})
-
-NodeExporterTypeDef = TypedDict("NodeExporterTypeDef", {"EnabledInBroker": bool})
-
-PrometheusTypeDef = TypedDict(
-    "PrometheusTypeDef",
-    {"JmxExporter": JmxExporterTypeDef, "NodeExporter": NodeExporterTypeDef},
-    total=False,
-)
-
-OpenMonitoringTypeDef = TypedDict("OpenMonitoringTypeDef", {"Prometheus": PrometheusTypeDef})
-
-MutableClusterInfoTypeDef = TypedDict(
-    "MutableClusterInfoTypeDef",
-    {
-        "BrokerEBSVolumeInfo": List[BrokerEBSVolumeInfoTypeDef],
-        "ConfigurationInfo": ConfigurationInfoTypeDef,
-        "NumberOfBrokerNodes": int,
-        "EnhancedMonitoring": Literal["DEFAULT", "PER_BROKER", "PER_TOPIC_PER_BROKER"],
-        "OpenMonitoring": OpenMonitoringTypeDef,
-        "KafkaVersion": str,
-        "LoggingInfo": LoggingInfoTypeDef,
-    },
-    total=False,
-)
-
-ClusterOperationInfoTypeDef = TypedDict(
-    "ClusterOperationInfoTypeDef",
-    {
-        "ClientRequestId": str,
-        "ClusterArn": str,
-        "CreationTime": datetime,
-        "EndTime": datetime,
-        "ErrorInfo": ErrorInfoTypeDef,
-        "OperationArn": str,
-        "OperationState": str,
-        "OperationSteps": List[ClusterOperationStepTypeDef],
-        "OperationType": str,
-        "SourceClusterInfo": MutableClusterInfoTypeDef,
-        "TargetClusterInfo": MutableClusterInfoTypeDef,
-    },
-    total=False,
-)
-
-DescribeClusterOperationResponseTypeDef = TypedDict(
-    "DescribeClusterOperationResponseTypeDef",
-    {"ClusterOperationInfo": ClusterOperationInfoTypeDef},
-    total=False,
-)
-
-BrokerSoftwareInfoTypeDef = TypedDict(
-    "BrokerSoftwareInfoTypeDef",
-    {"ConfigurationArn": str, "ConfigurationRevision": int, "KafkaVersion": str},
-    total=False,
-)
+EBSStorageInfoTypeDef = TypedDict("EBSStorageInfoTypeDef", {"VolumeSize": int}, total=False)
 
 EncryptionAtRestTypeDef = TypedDict("EncryptionAtRestTypeDef", {"DataVolumeKMSKeyId": str})
 
@@ -280,40 +246,144 @@ EncryptionInTransitTypeDef = TypedDict(
 EncryptionInfoTypeDef = TypedDict(
     "EncryptionInfoTypeDef",
     {
-        "EncryptionAtRest": EncryptionAtRestTypeDef,
-        "EncryptionInTransit": EncryptionInTransitTypeDef,
+        "EncryptionAtRest": "EncryptionAtRestTypeDef",
+        "EncryptionInTransit": "EncryptionInTransitTypeDef",
     },
     total=False,
 )
 
+ErrorInfoTypeDef = TypedDict(
+    "ErrorInfoTypeDef", {"ErrorCode": str, "ErrorString": str}, total=False
+)
+
+_RequiredFirehoseTypeDef = TypedDict("_RequiredFirehoseTypeDef", {"Enabled": bool})
+_OptionalFirehoseTypeDef = TypedDict(
+    "_OptionalFirehoseTypeDef", {"DeliveryStream": str}, total=False
+)
+
+
+class FirehoseTypeDef(_RequiredFirehoseTypeDef, _OptionalFirehoseTypeDef):
+    pass
+
+
+JmxExporterInfoTypeDef = TypedDict("JmxExporterInfoTypeDef", {"EnabledInBroker": bool})
+
+JmxExporterTypeDef = TypedDict("JmxExporterTypeDef", {"EnabledInBroker": bool})
+
+KafkaVersionTypeDef = TypedDict(
+    "KafkaVersionTypeDef", {"Version": str, "Status": Literal["ACTIVE", "DEPRECATED"]}, total=False
+)
+
+LoggingInfoTypeDef = TypedDict("LoggingInfoTypeDef", {"BrokerLogs": "BrokerLogsTypeDef"})
+
+MutableClusterInfoTypeDef = TypedDict(
+    "MutableClusterInfoTypeDef",
+    {
+        "BrokerEBSVolumeInfo": List["BrokerEBSVolumeInfoTypeDef"],
+        "ConfigurationInfo": "ConfigurationInfoTypeDef",
+        "NumberOfBrokerNodes": int,
+        "EnhancedMonitoring": Literal["DEFAULT", "PER_BROKER", "PER_TOPIC_PER_BROKER"],
+        "OpenMonitoring": "OpenMonitoringTypeDef",
+        "KafkaVersion": str,
+        "LoggingInfo": "LoggingInfoTypeDef",
+    },
+    total=False,
+)
+
+NodeExporterInfoTypeDef = TypedDict("NodeExporterInfoTypeDef", {"EnabledInBroker": bool})
+
+NodeExporterTypeDef = TypedDict("NodeExporterTypeDef", {"EnabledInBroker": bool})
+
+NodeInfoTypeDef = TypedDict(
+    "NodeInfoTypeDef",
+    {
+        "AddedToClusterTime": str,
+        "BrokerNodeInfo": "BrokerNodeInfoTypeDef",
+        "InstanceType": str,
+        "NodeARN": str,
+        "NodeType": Literal["BROKER"],
+        "ZookeeperNodeInfo": "ZookeeperNodeInfoTypeDef",
+    },
+    total=False,
+)
+
+OpenMonitoringTypeDef = TypedDict("OpenMonitoringTypeDef", {"Prometheus": "PrometheusTypeDef"})
+
+PrometheusInfoTypeDef = TypedDict(
+    "PrometheusInfoTypeDef",
+    {"JmxExporter": "JmxExporterInfoTypeDef", "NodeExporter": "NodeExporterInfoTypeDef"},
+    total=False,
+)
+
+PrometheusTypeDef = TypedDict(
+    "PrometheusTypeDef",
+    {"JmxExporter": "JmxExporterTypeDef", "NodeExporter": "NodeExporterTypeDef"},
+    total=False,
+)
+
+_RequiredS3TypeDef = TypedDict("_RequiredS3TypeDef", {"Enabled": bool})
+_OptionalS3TypeDef = TypedDict("_OptionalS3TypeDef", {"Bucket": str, "Prefix": str}, total=False)
+
+
+class S3TypeDef(_RequiredS3TypeDef, _OptionalS3TypeDef):
+    pass
+
+
 StateInfoTypeDef = TypedDict("StateInfoTypeDef", {"Code": str, "Message": str}, total=False)
 
-ClusterInfoTypeDef = TypedDict(
-    "ClusterInfoTypeDef",
+StorageInfoTypeDef = TypedDict(
+    "StorageInfoTypeDef", {"EbsStorageInfo": "EBSStorageInfoTypeDef"}, total=False
+)
+
+TlsTypeDef = TypedDict("TlsTypeDef", {"CertificateAuthorityArnList": List[str]}, total=False)
+
+ZookeeperNodeInfoTypeDef = TypedDict(
+    "ZookeeperNodeInfoTypeDef",
+    {
+        "AttachedENIId": str,
+        "ClientVpcIpAddress": str,
+        "Endpoints": List[str],
+        "ZookeeperId": float,
+        "ZookeeperVersion": str,
+    },
+    total=False,
+)
+
+CreateClusterResponseTypeDef = TypedDict(
+    "CreateClusterResponseTypeDef",
     {
-        "ActiveOperationArn": str,
-        "BrokerNodeGroupInfo": BrokerNodeGroupInfoTypeDef,
-        "ClientAuthentication": ClientAuthenticationTypeDef,
         "ClusterArn": str,
         "ClusterName": str,
-        "CreationTime": datetime,
-        "CurrentBrokerSoftwareInfo": BrokerSoftwareInfoTypeDef,
-        "CurrentVersion": str,
-        "EncryptionInfo": EncryptionInfoTypeDef,
-        "EnhancedMonitoring": Literal["DEFAULT", "PER_BROKER", "PER_TOPIC_PER_BROKER"],
-        "OpenMonitoring": OpenMonitoringTypeDef,
-        "LoggingInfo": LoggingInfoTypeDef,
-        "NumberOfBrokerNodes": int,
         "State": Literal["ACTIVE", "CREATING", "UPDATING", "DELETING", "FAILED"],
-        "StateInfo": StateInfoTypeDef,
-        "Tags": Dict[str, str],
-        "ZookeeperConnectString": str,
     },
     total=False,
 )
 
+CreateConfigurationResponseTypeDef = TypedDict(
+    "CreateConfigurationResponseTypeDef",
+    {
+        "Arn": str,
+        "CreationTime": datetime,
+        "LatestRevision": "ConfigurationRevisionTypeDef",
+        "Name": str,
+    },
+    total=False,
+)
+
+DeleteClusterResponseTypeDef = TypedDict(
+    "DeleteClusterResponseTypeDef",
+    {"ClusterArn": str, "State": Literal["ACTIVE", "CREATING", "UPDATING", "DELETING", "FAILED"]},
+    total=False,
+)
+
+DescribeClusterOperationResponseTypeDef = TypedDict(
+    "DescribeClusterOperationResponseTypeDef",
+    {"ClusterOperationInfo": "ClusterOperationInfoTypeDef"},
+    total=False,
+)
+
 DescribeClusterResponseTypeDef = TypedDict(
-    "DescribeClusterResponseTypeDef", {"ClusterInfo": ClusterInfoTypeDef}, total=False
+    "DescribeClusterResponseTypeDef", {"ClusterInfo": "ClusterInfoTypeDef"}, total=False
 )
 
 DescribeConfigurationResponseTypeDef = TypedDict(
@@ -323,7 +393,7 @@ DescribeConfigurationResponseTypeDef = TypedDict(
         "CreationTime": datetime,
         "Description": str,
         "KafkaVersions": List[str],
-        "LatestRevision": ConfigurationRevisionTypeDef,
+        "LatestRevision": "ConfigurationRevisionTypeDef",
         "Name": str,
     },
     total=False,
@@ -347,105 +417,45 @@ GetBootstrapBrokersResponseTypeDef = TypedDict(
     total=False,
 )
 
-CompatibleKafkaVersionTypeDef = TypedDict(
-    "CompatibleKafkaVersionTypeDef",
-    {"SourceVersion": str, "TargetVersions": List[str]},
-    total=False,
-)
-
 GetCompatibleKafkaVersionsResponseTypeDef = TypedDict(
     "GetCompatibleKafkaVersionsResponseTypeDef",
-    {"CompatibleKafkaVersions": List[CompatibleKafkaVersionTypeDef]},
+    {"CompatibleKafkaVersions": List["CompatibleKafkaVersionTypeDef"]},
     total=False,
 )
 
 ListClusterOperationsResponseTypeDef = TypedDict(
     "ListClusterOperationsResponseTypeDef",
-    {"ClusterOperationInfoList": List[ClusterOperationInfoTypeDef], "NextToken": str},
+    {"ClusterOperationInfoList": List["ClusterOperationInfoTypeDef"], "NextToken": str},
     total=False,
 )
 
 ListClustersResponseTypeDef = TypedDict(
     "ListClustersResponseTypeDef",
-    {"ClusterInfoList": List[ClusterInfoTypeDef], "NextToken": str},
+    {"ClusterInfoList": List["ClusterInfoTypeDef"], "NextToken": str},
     total=False,
 )
 
 ListConfigurationRevisionsResponseTypeDef = TypedDict(
     "ListConfigurationRevisionsResponseTypeDef",
-    {"NextToken": str, "Revisions": List[ConfigurationRevisionTypeDef]},
+    {"NextToken": str, "Revisions": List["ConfigurationRevisionTypeDef"]},
     total=False,
 )
 
-ConfigurationTypeDef = TypedDict(
-    "ConfigurationTypeDef",
-    {
-        "Arn": str,
-        "CreationTime": datetime,
-        "Description": str,
-        "KafkaVersions": List[str],
-        "LatestRevision": ConfigurationRevisionTypeDef,
-        "Name": str,
-    },
-)
-
 ListConfigurationsResponseTypeDef = TypedDict(
     "ListConfigurationsResponseTypeDef",
-    {"Configurations": List[ConfigurationTypeDef], "NextToken": str},
+    {"Configurations": List["ConfigurationTypeDef"], "NextToken": str},
     total=False,
 )
 
-KafkaVersionTypeDef = TypedDict(
-    "KafkaVersionTypeDef", {"Version": str, "Status": Literal["ACTIVE", "DEPRECATED"]}, total=False
-)
-
 ListKafkaVersionsResponseTypeDef = TypedDict(
     "ListKafkaVersionsResponseTypeDef",
-    {"KafkaVersions": List[KafkaVersionTypeDef], "NextToken": str},
-    total=False,
-)
-
-BrokerNodeInfoTypeDef = TypedDict(
-    "BrokerNodeInfoTypeDef",
-    {
-        "AttachedENIId": str,
-        "BrokerId": float,
-        "ClientSubnet": str,
-        "ClientVpcIpAddress": str,
-        "CurrentBrokerSoftwareInfo": BrokerSoftwareInfoTypeDef,
-        "Endpoints": List[str],
-    },
-    total=False,
-)
-
-ZookeeperNodeInfoTypeDef = TypedDict(
-    "ZookeeperNodeInfoTypeDef",
-    {
-        "AttachedENIId": str,
-        "ClientVpcIpAddress": str,
-        "Endpoints": List[str],
-        "ZookeeperId": float,
-        "ZookeeperVersion": str,
-    },
-    total=False,
-)
-
-NodeInfoTypeDef = TypedDict(
-    "NodeInfoTypeDef",
-    {
-        "AddedToClusterTime": str,
-        "BrokerNodeInfo": BrokerNodeInfoTypeDef,
-        "InstanceType": str,
-        "NodeARN": str,
-        "NodeType": Literal["BROKER"],
-        "ZookeeperNodeInfo": ZookeeperNodeInfoTypeDef,
-    },
+    {"KafkaVersions": List["KafkaVersionTypeDef"], "NextToken": str},
     total=False,
 )
 
 ListNodesResponseTypeDef = TypedDict(
     "ListNodesResponseTypeDef",
-    {"NextToken": str, "NodeInfoList": List[NodeInfoTypeDef]},
+    {"NextToken": str, "NodeInfoList": List["NodeInfoTypeDef"]},
     total=False,
 )
 
@@ -453,18 +463,8 @@ ListTagsForResourceResponseTypeDef = TypedDict(
     "ListTagsForResourceResponseTypeDef", {"Tags": Dict[str, str]}, total=False
 )
 
-JmxExporterInfoTypeDef = TypedDict("JmxExporterInfoTypeDef", {"EnabledInBroker": bool})
-
-NodeExporterInfoTypeDef = TypedDict("NodeExporterInfoTypeDef", {"EnabledInBroker": bool})
-
-PrometheusInfoTypeDef = TypedDict(
-    "PrometheusInfoTypeDef",
-    {"JmxExporter": JmxExporterInfoTypeDef, "NodeExporter": NodeExporterInfoTypeDef},
-    total=False,
-)
-
 OpenMonitoringInfoTypeDef = TypedDict(
-    "OpenMonitoringInfoTypeDef", {"Prometheus": PrometheusInfoTypeDef}
+    "OpenMonitoringInfoTypeDef", {"Prometheus": "PrometheusInfoTypeDef"}
 )
 
 PaginatorConfigTypeDef = TypedDict(
